import { formatearFechaHora } from "@/feature/messenger/utils/DateFormat";
import ConversationOptions from "./ConversationOptions";
import { Chip } from "@nextui-org/react";
import { getNameBySocial } from "@/feature/messenger/utils/TransFormName";
import useTagsStore from "@/feature/messenger/store/useTagsStore";
import truncateText from "@/feature/messenger/utils/TruncateText";
import Tags from "@/feature/messenger/components/ui/badges/Tags";


export default function ItemsConversation({ chatlist, changeChatClick, id_chatbot, selectedConversation }: { chatlist: any, changeChatClick: any, id_chatbot: string, selectedConversation: any }) {

    const nameUser = getNameBySocial(chatlist.nombre, chatlist.sesion, chatlist.rsocial);
    const message = chatlist.tipomensaje == "text" ? chatlist.conversacion : "Archivo";
    const unread = chatlist.sinLeer > 0 ? <Chip color="danger" radius="full" size="sm" className="text-center flex justify-center items-center">{chatlist.sinLeer}</Chip> : ""
    const active = "active-conversation";
    const currentUser = selectedConversation.sesion !== '' ? selectedConversation.sesion : null;
    const handleOpenTagsModal = useTagsStore(state => state.handleOpenTagsModal);
    const fetchTags = useTagsStore(state => state.fetchTags);

    // Asumimos que chatlist.tags es un array de objetos tag
    const visibleTags =  chatlist.tags.slice(0, 2);
    const additionalTags = chatlist.tags.length > 2 ? chatlist.tags.length - 2 : 0;

    const handleTagClick = (e: React.MouseEvent) => {
        e.stopPropagation();
        //fetchTags(chatlist.sesion, Number(id_chatbot));
        //handleOpenTagsModal()

    };

    return (
        <>
            <li className={`${chatlist.sesion == currentUser ? active : ""} ${chatlist.alerta_demora == 'SI' ? "alert-timeout-conversation" : ""} w-full m-1 cursor-pointer hover:bg-gray-500 hover:bg-opacity-35 hover:transition hover:duration-300`} onClick={(e) => changeChatClick(e, chatlist)}>
                <div className="flex justify-center items-center p-2 ">
                    {/* Logo */}
                    <div className="flex-shrink-0">
                        <img className="size-12 md:size-14 lg:size-16 rounded-full m-1 min-w-12 sm:min-w-12 md:min-w-14 lg:min-w-16" src={`${process.env.ASSET_PREFIX || ''}/chat/assets/images/contact/${chatlist.rsocial}.png`} alt="Profile Picture" />
                    </div>

                    {/* Header */}
                    <div className="truncate text-ellipsis capitalize m-1 w-full">
                        <div className="flex justify-between">
                            <h5 className="text-black truncate font-bold text-ellipsis capitalize dark:text-white" title={nameUser}>{nameUser}</h5>
                            {/* Status */}
                            <span className="text-xs text-gray-600 w-auto inline-flex dark:text-white">{formatearFechaHora(chatlist.fecha)}</span>
                        </div>
                        <div className="flex justify-between w-full">
                            <div>
                                <p className="text-sm text-gray-600 truncate dark:text-white">{truncateText(message, 25)}</p>
                                <Tags visibleTags={visibleTags} additionalTags={additionalTags} />
                            </div>
                            {/* Status and Options */}
                            <div className="inline-flex flex-col justify-between items-center">
                                {/* Options */}
                                <ConversationOptions id_chatbot={id_chatbot} selectedConversation={chatlist} />
                                <p className="text-xs text-gray-600">
                                    {unread}
                                </p>
                            </div>
                        </div>
                    </div>
                </div>
            </li>
        </>
    )
}
